==> haskell-wai-conduit-3.0.0.4-573-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-conduit
version:              3.0.0.4
visibility:           public
id:                   wai-conduit-3.0.0.4-KQUdS0NU3yq10ZUrJRki7F
key:                  wai-conduit-3.0.0.4-KQUdS0NU3yq10ZUrJRki7F
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.

category:             Web, Conduit
abi:                  5d391eb5e6802fd026755e7d56c81e98
exposed:              True
exposed-modules:      Network.Wai.Conduit
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-conduit-3.0.0.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-conduit
hs-libraries:         HSwai-conduit-3.0.0.4-KQUdS0NU3yq10ZUrJRki7F
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.6-6olN0R4zhzQGfJxY5P1sQG
    http-types-0.12.4-6kOruwBLItLEcotK7uAwKL transformers-0.5.6.2
    wai-3.2.4-4FGE67nPXB9CBfEQ1pErUn

haddock-interfaces:   /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html:         /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-conduit-3.0.0.4-575-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-conduit
version:              3.0.0.4
visibility:           public
id:                   wai-conduit-3.0.0.4-IWOG5iIK5LtQjgW2mZz0G
key:                  wai-conduit-3.0.0.4-IWOG5iIK5LtQjgW2mZz0G
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.

category:             Web, Conduit
abi:                  6e88a8449d8a81d15b654775b1dfd647
exposed:              True
exposed-modules:      Network.Wai.Conduit
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-conduit-3.0.0.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-conduit
hs-libraries:         HSwai-conduit-3.0.0.4-IWOG5iIK5LtQjgW2mZz0G
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.6-GKnHuzD4Nn6IarMahEfIxq
    http-types-0.12.4-G97153ZIeGq6X7uXEs2l2V transformers-0.5.6.2
    wai-3.2.4-BNQtAxBTTmbBe7Crr2a2xg

haddock-interfaces:   /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html:         /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
